@@ -1408,7 +1408,7 @@ class GitRepository(object):
         @param parents: parents of this commit
         @param author: authorship information
         @type author: C{dict} with keys 'name' and 'email' or L{GitModifier}
-        @param committer: comitter information
+        @param committer: committer information
         @type committer: C{dict} with keys 'name' and 'email'
         """
         extra_env = {}
@@ -1529,7 +1529,8 @@ class GitRepository(object):
         """
         commit_sha1 = self.rev_parse("%s^0" % commitish)
         args = GitArgs('--pretty=format:%an%x00%ae%x00%ad%x00%cn%x00%ce%x00%cd%x00%s%x00%f%x00%b%x00',
-                       '-z', '--date=raw', '--name-status', commit_sha1)
+                       '-z', '--date=raw', '--no-renames', '--name-status',
+                       commit_sha1)
         out, err, ret =  self._git_inout('show', args.args)
         if ret:
             raise GitRepositoryError("Unable to retrieve commit info for %s"
