@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 #
-# (C) 2006-2013 Guido Günther <agx@sigxcpu.org>
+# (C) 2006-2014 Guido Günther <agx@sigxcpu.org>
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation; either version 2 of the License, or
@@ -241,6 +241,8 @@ def pristine_tar_build_orig(repo, cp, output_dir, options):
 def get_upstream_tree(repo, cp, options):
     """Determine the upstream tree from the given options"""
     if options.upstream_tree.upper() == 'TAG':
+        if cp['Upstream-Version'] is None:
+            raise GitRepositoryError("Can't determine upstream version from changelog")
         upstream_tree = repo.version_to_tag(options.upstream_tag,
                                             cp['Upstream-Version'])
     elif options.upstream_tree.upper() == 'BRANCH':
@@ -365,20 +367,12 @@ def changes_file_suffix(dpkg_args):
         return os.getenv('ARCH', None) or du.get_arch()
 
 
-def parse_args(argv, prefix):
-    args = [ arg for arg in argv[1:] if arg.find('--%s' % prefix) == 0 ]
-    dpkg_args = [ arg for arg in argv[1:] if arg.find('--%s' % prefix) == -1 ]
-
-    # We handle these although they don't have a --git- prefix
-    for arg in [ "--help", "-h", "--version" ]:
-        if arg in dpkg_args:
-            args.append(arg)
-
+def build_parser(name, prefix=None):
     try:
-        parser = GbpOptionParserDebian(command=os.path.basename(argv[0]), prefix=prefix)
+        parser = GbpOptionParserDebian(command=os.path.basename(name), prefix=prefix)
     except ConfigParser.ParsingError as err:
         gbp.log.err(err)
-        return None, None, None
+        return None
 
     tag_group = GbpOptionGroup(parser, "tag options", "options related to git tag creation")
     branch_group = GbpOptionGroup(parser, "branch options", "branch layout options")
@@ -453,6 +447,21 @@ def parse_args(argv, prefix):
     export_group.add_option("--git-dont-purge", action="store_true", dest="dont_purge", default=False,
                             help="deprecated, use --git-no-purge instead")
     export_group.add_boolean_config_file_option(option_name="overlay", dest="overlay")
+    return parser
+
+
+def parse_args(argv, prefix):
+    args = [ arg for arg in argv[1:] if arg.find('--%s' % prefix) == 0 ]
+    dpkg_args = [ arg for arg in argv[1:] if arg.find('--%s' % prefix) == -1 ]
+
+    # We handle these although they don't have a --git- prefix
+    for arg in [ "--help", "-h", "--version" ]:
+        if arg in dpkg_args:
+            args.append(arg)
+
+    parser = build_parser(argv[0], prefix=prefix)
+    if not parser:
+        return None, None, None
     options, args = parser.parse_args(args)
 
     gbp.log.setup(options.color, options.verbose, options.color_scheme)
@@ -475,6 +484,13 @@ def parse_args(argv, prefix):
     return options, args, dpkg_args
 
 
+class Hook(RunAtCommand):
+    "A hook run during the build"
+    def __init__(self, name, *args, **kwargs):
+        RunAtCommand.__init__(self, *args, **kwargs)
+        self.run_error = '%s-hook %s' % (name, self.run_error)
+
+
 def main(argv):
     retval = 0
     prefix = "git-"
@@ -540,9 +556,9 @@ def main(argv):
 
                 # Run postexport hook
                 if options.postexport:
-                    RunAtCommand(options.postexport, shell=True,
-                                 extra_env={'GBP_GIT_DIR': repo.git_dir,
-                                            'GBP_TMP_DIR': tmp_dir})(dir=tmp_dir)
+                    Hook('Postexport', options.postexport, shell=True,
+                         extra_env={'GBP_GIT_DIR': repo.git_dir,
+                                    'GBP_TMP_DIR': tmp_dir})(dir=tmp_dir)
 
                 major = (source.changelog.debian_version if source.is_native()
                          else source.changelog.upstream_version)
@@ -562,9 +578,9 @@ def main(argv):
                 build_dir = repo_dir
 
             if options.prebuild:
-                RunAtCommand(options.prebuild, shell=True,
-                             extra_env={'GBP_GIT_DIR': repo.git_dir,
-                                        'GBP_BUILD_DIR': build_dir})(dir=build_dir)
+                Hook('Prebuild', options.prebuild, shell=True,
+                     extra_env={'GBP_GIT_DIR': repo.git_dir,
+                                'GBP_BUILD_DIR': build_dir})(dir=build_dir)
 
             setup_pbuilder(options)
             # Finally build the package:
@@ -577,9 +593,9 @@ def main(argv):
                                            source.changelog.noepoch,
                                            changes_file_suffix(dpkg_args)))
                 gbp.log.debug("Looking for changes file %s" % changes)
-                Command(options.postbuild, shell=True,
-                        extra_env={'GBP_CHANGES_FILE': changes,
-                                   'GBP_BUILD_DIR': build_dir})()
+                Hook('Postbuild', options.postbuild, shell=True,
+                     extra_env={'GBP_CHANGES_FILE': changes,
+                                'GBP_BUILD_DIR': build_dir})()
         if options.tag or options.tag_only:
             gbp.log.info("Tagging %s" % source.changelog.version)
             tag = repo.version_to_tag(options.debian_tag, source.changelog.version)
@@ -591,10 +607,10 @@ def main(argv):
                             sign=options.sign_tags, keyid=options.keyid)
             if options.posttag:
                 sha = repo.rev_parse("%s^{}" % tag)
-                Command(options.posttag, shell=True,
-                        extra_env={'GBP_TAG': tag,
-                                   'GBP_BRANCH': branch or '(no branch)',
-                                   'GBP_SHA1': sha})()
+                Hook('Posttag', options.posttag, shell=True,
+                     extra_env={'GBP_TAG': tag,
+                                'GBP_BRANCH': branch or '(no branch)',
+                                'GBP_SHA1': sha})()
     except CommandExecFailed:
         retval = 1
     except (GbpError, GitRepositoryError) as err:
